from .. import WidgetHandlerManager
from .. import AbstractItem
from . import QGraphicsWidget

class Lancelot__WidgetHandler(QGraphicsWidget.QGraphicsWidgetHandler):
    def name(self):
        return "Lancelot::Widget"

    def include(self):
        includes = "lancelot/widgets/Widget.h QString".split(" ")
        includesCode = ""
        for include in includes:
            if (include != ""):
                includesCode += "#include<" + include + ">\n"
        return includesCode


    def setup(self):
        setup = QGraphicsWidget.QGraphicsWidgetHandler.setup(self)


        if self.hasAttribute('group'):
            setup += self.attribute('name') \
                  + '->setGroupByName("' + self.attribute('group') + '");'

        if self.hasAttribute('down'):
            setup += self.attribute('name') \
                  + '->setDown(' + self.attribute('down') + ');'


        return setup;

WidgetHandlerManager.addHandler(Lancelot__WidgetHandler())





#  Copyright (C) 2007, 2008, 2009, 2010 Ivan Cukic <ivan.cukic(at)kde.org>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License version 2,
#  or (at your option) any later version, as published by the Free
#  Software Foundation
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU General Public License for more details
#
#  You should have received a copy of the GNU General Public
#  License along with this program; if not, write to the
#  Free Software Foundation, Inc.,
#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.


__handlers = {};

def handlers():
    return __handlers

def handler(layoutName):
    if not __handlers.has_key(layoutName):
        print "WARNING: Layout has no handler ", layoutName, " USING DEFAULT HANDLER"
        return __handlers["Abstract"]
    return __handlers[layoutName]

def addHandler(handler):
    __handlers[handler.name()] = handler



from .. import WidgetHandlerManager
from .. import AbstractItem
from . import Plasma__ScrollBar

class Lancelot__ScrollBarHandler(Plasma__ScrollBar.Plasma__ScrollBarHandler):
    def name(self):
        return "Lancelot::ScrollBar"

    def include(self):
        includes = "lancelot/widgets/ScrollBar.h lancelot/lancelot.h".split(" ")
        includesCode = ""
        for include in includes:
            if (include != ""):
                includesCode += "#include<" + include + ">\n"
        return includesCode


    def setup(self):
        setup = Plasma__ScrollBar.Plasma__ScrollBarHandler.setup(self)


        if self.hasAttribute('activationMethod'):
            setup += self.attribute('name') \
                  + '->setActivationMethod(' + self.attribute('activationMethod') + ');'


        return setup;

WidgetHandlerManager.addHandler(Lancelot__ScrollBarHandler())





from .. import WidgetHandlerManager
from .. import AbstractItem
from . import Lancelot__Widget

class Lancelot__BasicWidgetHandler(Lancelot__Widget.Lancelot__WidgetHandler):
    def name(self):
        return "Lancelot::BasicWidget"

    def include(self):
        includes = "lancelot/widgets/BasicWidget.h QIcon QSize QString".split(" ")
        includesCode = ""
        for include in includes:
            if (include != ""):
                includesCode += "#include<" + include + ">\n"
        return includesCode


    def setup(self):
        setup = Lancelot__Widget.Lancelot__WidgetHandler.setup(self)


        if self.hasAttribute('icon'):
            setup += self.attribute('name') \
                  + '->setIcon(KIcon("' + self.attribute('icon') + '"));'

        if self.hasAttribute('iconSize'):
            setup += self.attribute('name') \
                  + '->setIconSize(QSize(' + self.attribute('iconSize') + '));'

        if self.hasAttribute('title'):
            setup += self.attribute('name') \
                  + '->setTitle(i18n("' + self.attribute('title') + '"));'

        if self.hasAttribute('description'):
            setup += self.attribute('name') \
                  + '->setDescription(i18n("' + self.attribute('description') + '"));'

        if self.hasAttribute('innerOrientation'):
            setup += self.attribute('name') \
                  + '->setInnerOrientation(Qt::' + self.attribute('innerOrientation') + ');'


        return setup;

WidgetHandlerManager.addHandler(Lancelot__BasicWidgetHandler())





from .. import WidgetHandlerManager
from .. import AbstractItem
from . import Lancelot__BasicWidget

class Lancelot__ExtenderButtonHandler(Lancelot__BasicWidget.Lancelot__BasicWidgetHandler):
    def name(self):
        return "Lancelot::ExtenderButton"

    def include(self):
        includes = "lancelot/widgets/ExtenderButton.h lancelot/lancelot.h".split(" ")
        includesCode = ""
        for include in includes:
            if (include != ""):
                includesCode += "#include<" + include + ">\n"
        return includesCode


    def setup(self):
        setup = Lancelot__BasicWidget.Lancelot__BasicWidgetHandler.setup(self)


        if self.hasAttribute('extenderPosition'):
            setup += self.attribute('name') \
                  + '->setExtenderPosition(' + self.attribute('extenderPosition') + ');'

        if self.hasAttribute('activationMethod'):
            setup += self.attribute('name') \
                  + '->setActivationMethod(' + self.attribute('activationMethod') + ');'

        if self.hasAttribute('checkable'):
            setup += self.attribute('name') \
                  + '->setCheckable(' + self.attribute('checkable') + ');'

        if self.hasAttribute('checked'):
            setup += self.attribute('name') \
                  + '->setChecked(' + self.attribute('checked') + ');'


        return setup;

WidgetHandlerManager.addHandler(Lancelot__ExtenderButtonHandler())





from .. import LayoutHandlerManager
from .  import AbstractLayout

import xml

class FullBorderLayoutHandler(AbstractLayout.AbstractLayoutHandler):
    def name(self):
        return "Lancelot::FullBorderLayout"

    def include(self):
        return "#include <lancelot/layouts/FullBorderLayout.h>"

    def setup(self):
        setup = AbstractLayout.AbstractLayoutHandler.setup(self)

        if self.hasAttribute("leftSize"):
            setup += self.attribute("name") + \
                     "->setSize(" + self.attribute("leftSize") + ", Lancelot::FullBorderLayout::LeftBorder);\n";
        if self.hasAttribute("rightSize"):
            setup += self.attribute("name") + \
                     "->setSize(" + self.attribute("rightSize") + ", Lancelot::FullBorderLayout::RightBorder);\n";
        if self.hasAttribute("topSize"):
            setup += self.attribute("name") + \
                     "->setSize(" + self.attribute("topSize") + ", Lancelot::FullBorderLayout::TopBorder);\n";
        if self.hasAttribute("bottomSize"):
            setup += self.attribute("name") + \
                    "->setSize(" + self.attribute("bottomSize") + ", Lancelot::FullBorderLayout::BottomBorder);\n";

        for child in self.node().childNodes:
            if not child.nodeType == xml.dom.Node.ELEMENT_NODE or not child.prefix == "item":
                continue

            setup += self.attribute("name") + "->addItem(" + child.getAttribute("name") + "," \
                    + " Lancelot::FullBorderLayout::" + child.getAttribute(self.namespace() + ":position") + ");\n"
        return setup

LayoutHandlerManager.addHandler(FullBorderLayoutHandler())



from .. import WidgetHandlerManager
from .. import AbstractItem
from . import QGraphicsWidget

class Lancelot__TabBarHandler(QGraphicsWidget.QGraphicsWidgetHandler):
    def name(self):
        return "Lancelot::TabBar"

    def include(self):
        includes = "lancelot/widgets/TabBar.h QIcon QSize QString".split(" ")
        includesCode = ""
        for include in includes:
            if (include != ""):
                includesCode += "#include<" + include + ">\n"
        return includesCode


    def setup(self):
        setup = QGraphicsWidget.QGraphicsWidgetHandler.setup(self)

        
        if self.hasAttribute('orientation'):
            setup += self.attribute('name') \
                  + '->setOrientation(Qt::' + self.attribute('orientation') + ');'
        
        if self.hasAttribute('textDirection'):
            setup += self.attribute('name') \
                  + '->setTextDirection(Qt::' + self.attribute('textDirection') + ');'
        
        if self.hasAttribute('currentTab'):
            setup += self.attribute('name') \
                  + '->setCurrentTab("' + self.attribute('currentTab') + '");'
        
        if self.hasAttribute('tabIconSize'):
            setup += self.attribute('name') \
                  + '->setTabIconSize(QSize(' + self.attribute('tabIconSize') + '));'
        

        return setup;

WidgetHandlerManager.addHandler(Lancelot__TabBarHandler())





#  Copyright (C) 2007, 2008, 2009, 2010 Ivan Cukic <ivan.cukic(at)kde.org>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License version 2,
#  or (at your option) any later version, as published by the Free
#  Software Foundation
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU General Public License for more details
#
#  You should have received a copy of the GNU General Public
#  License along with this program; if not, write to the
#  Free Software Foundation, Inc.,
#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

import sys, traceback

def message(msg, var):
    print >> sys.stdout, "-" * 10 + " : ",  msg, " ", var

def trace(msg):
    print msg, ' - Trace ', '-' * 60
    try:
        raise NameError, 'HiThere'
    except:
        traceback.print_exc(None, sys.stdout)
        traceback.print_stack()
    print '- End Trace ', '-' * 60



from .. import LayoutHandlerManager
from .  import AbstractLayout

import xml

class CardLayoutHandler(AbstractLayout.AbstractLayoutHandler):
    def name(self):
        return 'Lancelot::CardLayout'

    def include(self):
        return '#include <lancelot/layouts/CardLayout.h>'

    def setup(self):
        setup = AbstractLayout.AbstractLayoutHandler.setup(self)

        for child in self.node().childNodes:
            if not child.nodeType == xml.dom.Node.ELEMENT_NODE or not child.prefix == 'item':
                continue

            line = self.attribute('name') + '->addItem(${ITEM_NAME}${CARD_NAME});';
            if child.hasAttribute(self.namespace() + ':cardName'):
                setup += line \
                    .replace('${ITEM_NAME}', child.getAttribute('name')) \
                    .replace('${CARD_NAME}', ((', "' + child.getAttribute(self.namespace() + ':cardName') + '"') \
                                               if child.hasAttribute(self.namespace() + ':cardName') else ''))
        return setup

LayoutHandlerManager.addHandler(CardLayoutHandler())



from .. import LayoutHandlerManager
from .  import AbstractLayout

class FlipLayoutHandler(AbstractLayout.AbstractLayoutHandler):
    def name(self):
        return "Lancelot::FlipLayout"

    def include(self):
        h = LayoutHandlerManager.handler(self.attribute("realLayout"))
        h.setNode(self.node())

        return h.include() + "\n#include <lancelot/layouts/FlipLayout.h>"

    def declaration(self):
        return "Lancelot::FlipLayout < " + self.attribute("realLayout") + " > * " + self.attribute("name") + ";"

    def initialization(self):
        return self.attribute("name") + " = new Lancelot::FlipLayout < " + self.attribute("realLayout") + " > ();"

    def setup(self):
        setup = ""
        if self.attribute("flip"):
            setup += self.attribute("name") + "->setFlip(" + self.attribute("flip") + ");\n";

        h = LayoutHandlerManager.handler(self.attribute("realLayout"))
        h.setNode(self.node())

        return setup + h.setup()

LayoutHandlerManager.addHandler(FlipLayoutHandler())



__all__ = [
    "Lancelot__ActionListView",
    "Lancelot__BasicWidget",
    "Lancelot__ExtenderButton",
    "Lancelot__Panel",
    "Lancelot__PassagewayView",
    "Lancelot__ResizeBordersPanel",
    "Lancelot__ScrollBar",
    "Lancelot__ScrollButton",
    "Lancelot__ScrollPane",
    "Lancelot__TabBar",
    "Lancelot__Widget",
    "QGraphicsLayoutItem",
    "QGraphicsLayout",
    "QGraphicsWidget"
]
